
Condition Classes
=================

Condition classes are the low level mechanics of the condition 
system. All conditions are instances of the condition classes.

There are also time period utilities that are used in the 
time related conditions. They determine whether a given time 
is inside a given time period, such as a given day of month, 
day of week, between  
